nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Cr

Struct Cr 

#[repr(transparent)]
pub struct Cr(pub u32);
GPT Control Register

Tuple Fields

0: u32

Implementations

Source

impl Cr

pub const fn en(&self) -> En

GPT Enable

pub const fn set_en(&mut self, val: En)

GPT Enable

pub const fn enmod(&self) -> Enmod

GPT Enable mode

pub const fn set_enmod(&mut self, val: Enmod)

GPT Enable mode

pub const fn dbgen(&self) -> Dbgen

GPT debug mode enable

pub const fn set_dbgen(&mut self, val: Dbgen)

GPT debug mode enable

pub const fn waiten(&self) -> Waiten

GPT Wait Mode enable

pub const fn set_waiten(&mut self, val: Waiten)

GPT Wait Mode enable

pub const fn dozeen(&self) -> Dozeen

GPT Doze Mode Enable

pub const fn set_dozeen(&mut self, val: Dozeen)

GPT Doze Mode Enable

pub const fn stopen(&self) -> Stopen

GPT Stop Mode enable

pub const fn set_stopen(&mut self, val: Stopen)

GPT Stop Mode enable

pub const fn clksrc(&self) -> Clksrc

Clock Source select

pub const fn set_clksrc(&mut self, val: Clksrc)

Clock Source select

pub const fn frr(&self) -> Frr

Free-Run or Restart mode

pub const fn set_frr(&mut self, val: Frr)

Free-Run or Restart mode

pub const fn en_24m(&self) -> En24m

Enable 24 MHz clock input from crystal

pub const fn set_en_24m(&mut self, val: En24m)

Enable 24 MHz clock input from crystal

pub const fn swr(&self) -> Swr

Software reset

pub const fn set_swr(&mut self, val: Swr)

Software reset

pub const fn im1(&self) -> u8

See IM2

pub const fn set_im1(&mut self, val: u8)

See IM2

pub const fn im2(&self) -> Im2

IM2 (bits 19-18, Input Capture Channel 2 operating mode) IM1 (bits 17-16, Input Capture Channel 1 operating mode) The IMn bit field determines the transition on the input pin (for Input capture channel n), which will trigger a capture event

pub const fn set_im2(&mut self, val: Im2)

IM2 (bits 19-18, Input Capture Channel 2 operating mode) IM1 (bits 17-16, Input Capture Channel 1 operating mode) The IMn bit field determines the transition on the input pin (for Input capture channel n), which will trigger a capture event

pub const fn om1(&self) -> u8

See OM3

pub const fn set_om1(&mut self, val: u8)

See OM3

pub const fn om2(&self) -> u8

See OM3

pub const fn set_om2(&mut self, val: u8)

See OM3

pub const fn om3(&self) -> Om3

OM3 (bits 28-26) controls the Output Compare Channel 3 operating mode

pub const fn set_om3(&mut self, val: Om3)

OM3 (bits 28-26) controls the Output Compare Channel 3 operating mode

pub const fn fo1(&self) -> bool

See F03

pub const fn set_fo1(&mut self, val: bool)

See F03

pub const fn fo2(&self) -> bool

See F03

pub const fn set_fo2(&mut self, val: bool)

See F03

pub const fn fo3(&self) -> Fo3

FO3 Force Output Compare Channel 3 FO2 Force Output Compare Channel 2 FO1 Force Output Compare Channel 1 The FOn bit causes the pin action programmed for the timer Output Compare n pin (according to the OMn bits in this register)

pub const fn set_fo3(&mut self, val: Fo3)

FO3 Force Output Compare Channel 3 FO2 Force Output Compare Channel 2 FO1 Force Output Compare Channel 1 The FOn bit causes the pin action programmed for the timer Output Compare n pin (according to the OMn bits in this register)