#[repr(transparent)]pub struct Ir(pub u32);Expand description
GPT Interrupt Register
Tuple Fields
0: u32Implementations
Sourceimpl Ir
impl Ir
Sourcepub const fn of3ie(&self) -> Of3ie
pub const fn of3ie(&self) -> Of3ie
OF3IE Output Compare 3 Interrupt Enable OF2IE Output Compare 2 Interrupt Enable OF1IE Output Compare 1 Interrupt Enable The OFnIE bit controls the Output Compare Channel n interrupt
Sourcepub const fn set_of3ie(&mut self, val: Of3ie)
pub const fn set_of3ie(&mut self, val: Of3ie)
OF3IE Output Compare 3 Interrupt Enable OF2IE Output Compare 2 Interrupt Enable OF1IE Output Compare 1 Interrupt Enable The OFnIE bit controls the Output Compare Channel n interrupt
Sourcepub const fn if2ie(&self) -> If2ie
pub const fn if2ie(&self) -> If2ie
IF2IE Input capture 2 Interrupt Enable IF1IE Input capture 1 Interrupt Enable The IFnIE bit controls the IFnIE Input Capture n Interrupt Enable
Sourcepub const fn set_if2ie(&mut self, val: If2ie)
pub const fn set_if2ie(&mut self, val: If2ie)
IF2IE Input capture 2 Interrupt Enable IF1IE Input capture 1 Interrupt Enable The IFnIE bit controls the IFnIE Input Capture n Interrupt Enable